darkhistory.history.tla — DarkHistory documentation

# darkhistory.history.tla

Three-level atom model and integrator.

Functions

`compton_cooling_rate`(xHII, xHeII, xHeIII, …) | Returns the Compton cooling rate.
`get_history`(rs_vec[, init_cond, f_H_ion, …]) | Returns the ionization and thermal history of the IGM.

#### Previous topic

darkhistory.history.reionization.recomb_cooling_rate

#### Next topic

darkhistory.history.tla.compton_cooling_rate

### This Page

Show Source